Plugin reference
================

:mod:`~PIL.BmpImagePlugin` Module
---------------------------------

.. automodule:: PIL.BmpImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.BufrStubImagePlugin` Module
--------------------------------------

.. automodule:: PIL.BufrStubImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.CurImagePlugin` Module
---------------------------------

.. automodule:: PIL.CurImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.DcxImagePlugin` Module
---------------------------------

.. automodule:: PIL.DcxImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.EpsImagePlugin` Module
---------------------------------

.. automodule:: PIL.EpsImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.FitsStubImagePlugin` Module
--------------------------------------

.. automodule:: PIL.FitsStubImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.FliImagePlugin` Module
---------------------------------

.. automodule:: PIL.FliImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.FpxImagePlugin` Module
---------------------------------

.. automodule:: PIL.FpxImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.GbrImagePlugin` Module
---------------------------------

.. automodule:: PIL.GbrImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.GifImagePlugin` Module
---------------------------------

.. automodule:: PIL.GifImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.GribStubImagePlugin` Module
--------------------------------------

.. automodule:: PIL.GribStubImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.Hdf5StubImagePlugin` Module
--------------------------------------

.. automodule:: PIL.Hdf5StubImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.IcnsImagePlugin` Module
----------------------------------

.. automodule:: PIL.IcnsImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.IcoImagePlugin` Module
---------------------------------

.. automodule:: PIL.IcoImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.ImImagePlugin` Module
--------------------------------

.. automodule:: PIL.ImImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.ImtImagePlugin` Module
---------------------------------

.. automodule:: PIL.ImtImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.IptcImagePlugin` Module
----------------------------------

.. automodule:: PIL.IptcImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.JpegImagePlugin` Module
----------------------------------

.. automodule:: PIL.JpegImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.Jpeg2KImagePlugin` Module
------------------------------------

.. automodule:: PIL.Jpeg2KImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.McIdasImagePlugin` Module
------------------------------------

.. automodule:: PIL.McIdasImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.MicImagePlugin` Module
---------------------------------

.. automodule:: PIL.MicImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.MpegImagePlugin` Module
----------------------------------

.. automodule:: PIL.MpegImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.MspImagePlugin` Module
---------------------------------

.. automodule:: PIL.MspImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.PalmImagePlugin` Module
----------------------------------

.. automodule:: PIL.PalmImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.PcdImagePlugin` Module
---------------------------------

.. automodule:: PIL.PcdImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.PcxImagePlugin` Module
---------------------------------

.. automodule:: PIL.PcxImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.PdfImagePlugin` Module
---------------------------------

.. automodule:: PIL.PdfImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.PixarImagePlugin` Module
-----------------------------------

.. automodule:: PIL.PixarImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.PngImagePlugin` Module
---------------------------------

.. automodule:: PIL.PngImagePlugin
    :members: ChunkStream, PngImageFile, PngStream, getchunks, is_cid, putchunk,
        MAX_TEXT_CHUNK, MAX_TEXT_MEMORY, APNG_BLEND_OP_SOURCE, APNG_BLEND_OP_OVER,
        APNG_DISPOSE_OP_NONE, APNG_DISPOSE_OP_BACKGROUND, APNG_DISPOSE_OP_PREVIOUS
    :undoc-members:
    :show-inheritance:
    :member-order: groupwise


:mod:`~PIL.PpmImagePlugin` Module
---------------------------------

.. automodule:: PIL.PpmImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.PsdImagePlugin` Module
---------------------------------

.. automodule:: PIL.PsdImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.SgiImagePlugin` Module
---------------------------------

.. automodule:: PIL.SgiImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.SpiderImagePlugin` Module
------------------------------------

.. automodule:: PIL.SpiderImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.SunImagePlugin` Module
---------------------------------

.. automodule:: PIL.SunImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.TgaImagePlugin` Module
---------------------------------

.. automodule:: PIL.TgaImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.TiffImagePlugin` Module
----------------------------------

.. automodule:: PIL.TiffImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.WebPImagePlugin` Module
----------------------------------

.. automodule:: PIL.WebPImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.WmfImagePlugin` Module
---------------------------------

.. automodule:: PIL.WmfImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.XVThumbImagePlugin` Module
-------------------------------------

.. automodule:: PIL.XVThumbImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.XbmImagePlugin` Module
---------------------------------

.. automodule:: PIL.XbmImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.XpmImagePlugin` Module
---------------------------------

.. automodule:: PIL.XpmImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:
